ModifierContinuation

Type Alias ModifierContinuation 

type ModifierContinuation<'gcx> = (&'gcx [Modifier<'gcx>], usize, Block<'gcx>, Option<VariableId>);
What to analyse when a modifier’s _ is reached: the remaining modifiers, the function body and the reentrancy-guard lock the current modifier holds.

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 56 bytes